@@ -3,6 +3,7 @@ from . import styles_cms as style
 from . import label as label_base
 from .label import lumitext
 import mplhep._deprecate as deprecate
+from matplotlib import docstring
 
 __all__ = [style, lumitext]
 
@@ -27,9 +28,11 @@ def cmstext(**kwargs):
     return _cms_text(**kwargs)
 
 
+@docstring.copy(label_base._exp_text)
 def text(*args, **kwargs):
     return _cms_text(*args, **kwargs)
 
 
+@docstring.copy(label_base._exp_label)
 def label(**kwargs):
     return _cms_label(**kwargs)
